#!/usr/bin/python
from gi.repository import Gtk
Gtk.require_version('2.0')
from gi.repository import Grip


# XXX For now, we'll use Grip directly. Once we have a good sense of what's
# going to be needed in general for general Python code using Grip, we might
# want to put that stuff in a wrapper grip module, and import everything from
# there instead.


class GestureTester(object):

    def __init__(self):
        builder = Gtk.Builder()
        builder.add_from_file("pygrip-gestures.xml")
        builder.connect_signals(self)
        self.window = builder.get_object("window1")
        self.gesture_manager = Grip.GestureManager()
        self.window.show()

    def window_mapped(self, widget, data=None):
        # The gesture manager is only going to be needed for GTK2, since GTK3
        # will have the gesture API natively. Conversely, pygrip will only be
        # for GTK2, since PyGTK3 will having the bindings.
 
        finger_count = 2
        self.gesture_manager.register_window(widget, Grip.GestureType.PINCH, finger_count, self.callback, None)

    def callback(self, window, time_type, gesture_event, data):
        print "received gesture"

    def quit(self, widget, data=None):
        Gtk.main_quit()


if __name__ == "__main__":
    app = GestureTester()
    Gtk.main()



#
# Copyright 2010 Canonical, Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of either or both of the following licenses:
#
# 1) the GNU Lesser General Public License version 3, as published by the
# Free Software Foundation; and/or
# 2) the GNU Lesser General Public License version 2.1, as published by
# the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
# PURPOSE.  See the applicable version of the GNU Lesser General Public
# License for more details.
#
# You should have received a copy of both the GNU Lesser General Public
# License version 3 and version 2.1 along with this program.  If not, see
# <http://www.gnu.org/licenses/>
#
# Authors:
#    Cody Russell <crussell@canonical.com>
#

from ..overrides import override
from ..importer import modules

Grip = modules['Grip']._introspection_module

__all__ = []

class GestureEvent(Grip.GestureEvent):
    _UNION_MEMBERS = {
        Grip.GestureType.DRAG: 'drag',
        Grip.GestureType.PINCH: 'pinch',
        Grip.GestureType.ROTATE: 'rotate',
        Grip.GestureType.TAP: 'tap'
    }

    def __new__(cls, *args, **kwargs):
        return Grip.GestureEvent.__new__(cls)

    def __getattr__(self, name):
        real_event = getattr(self, '_UNION_MEMBERS').get(self.type)
        if real_event:
            return getattr(getattr(self, real_event), name)
        else:
            return getattr(self, name)

GestureEvent = override(GestureEvent)
__all__.append('GestureEvent')
